browser

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 4, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetChromeVersion

func GetChromeVersion(opts *uagenerator.Options, rng *rand.Rand) uagenerator.ChromiumVersion

GetChromeVersion returns a randomly selected Chrome version, filtered by options.

func GetEdgeVersion

func GetEdgeVersion(opts *uagenerator.Options, rng *rand.Rand) uagenerator.ChromiumVersion

GetEdgeVersion returns a randomly selected Edge version, filtered by options.

func GetFirefoxVersion

func GetFirefoxVersion(opts *uagenerator.Options, rng *rand.Rand) uagenerator.Version

GetFirefoxVersion returns a randomly selected Firefox version, filtered by options.

func GetSafariVersion

func GetSafariVersion(opts *uagenerator.Options, rng *rand.Rand, platformVersion uagenerator.Version) uagenerator.SafariVersion

GetSafariVersion returns a randomly selected Safari version, filtered by options. If TiedSafariVersion is set, the returned version matches platformVersion.

Types

This section is empty.

Jump to